@@ -143,10 +143,6 @@ class HgDialect(object):
                             % (command_name))
         return local_command
     
-    def get_dialect_command(self, context, command_name, args):
-        """Looks up a Mercurial-specific command."""
-        local_command = self.get_dialect_command_class(command_name)
-        return local_command.from_args(context, args)
     
     def cwd_is_this_dialect(self):
         """Returns 1 if the .hg directory is here, 0 otherwise."""
