@@ -127,4 +127,38 @@ A      baz.txt
     assert result.get_command_line() == ["svn", "resolve", 
         "--accept", "working", "bar.txt"]
     assert rid.called
+    
+class T(object):
+    def __init__(self, command, error=False):
+        self.command = command
+        self.error = error
+        
+    @property
+    def args(self):
+        return ["svn"] + self.command.split(" ")
+        
+def test_svn_native_commands():
+    tests = [
+        T("revert"),
+        T("revert -R"),
+        T("revert --foo", error=True),
+        T("revert -h"),
+        T("revert --help")
+    ]
+    
+    def test_one(t):
+        try:
+            command = main.convert(context, t.args, None)
+        except svn.SVNError, e:
+            if t.error:
+                return
+            else:
+                assert False, "Unexpected Exception: %s" % e
+                
+        command_line = command.get_command_line()
+        args = t.args
+        assert command_line == args
+    
+    for t in tests:
+        yield test_one, t
     
\ No newline at end of file
